@@ -21,6 +21,9 @@ foreach (qw(
     infrastructure issues jobs lfs monitor mr packages pages releases
     repo request_access requirements security_compliance service_desk snippets
     wiki
+    no_wait
+    dep14
+    branch ref commit_message content_from_file
     avatar_path desc desc_pattern
     email disable_email email_recipient
     irc_channel
@@ -92,6 +95,7 @@ use constant keys => [
     # Responses
     ['yes!',    'SALSA_YES',     sub { info(1, "SALSA_YES", @_) }],
     ['no-fail', 'SALSA_NO_FAIL', 'bool'],
+    ['no-wait', 'SALSA_NO_WAIT', 'bool'],
 
     # Output
     ['verbose!', 'SALSA_VERBOSE', sub { $verbose = 1 }],
@@ -128,7 +132,8 @@ use constant keys => [
     ['all'],
     ['all-archived'],
     ['archived!', 'SALSA_ARCHIVED', 'bool', 0],
-    ['skip=s',    'SALSA_SKIP',     undef,  sub { [] }],
+    ['ref=s'],
+    ['skip=s', 'SALSA_SKIP', undef, sub { [] }],
     [
         'skip-file=s',
         'SALSA_SKIP_FILE',
@@ -313,6 +318,8 @@ use constant keys => [
     ],
 
     # Branch
+    ['dep14!', 'SALSA_DEP14', 'bool'],
+    ['branch|b=s'],
     ['rename-head!',    'SALSA_RENAME_HEAD',   'bool'],
     ['source-branch=s', 'SALSA_SOURCE_BRANCH', undef, 'master'],
     ['debian-branch=s', 'SALSA_DEBIAN_BRANCH'],
@@ -347,6 +354,10 @@ use constant keys => [
     # Last-CI options
     ['retry-failed-pipelines', 'SALSA_RETRY_FAILED_PIPELINES', 'bool', 0],
 
+    # File options
+    ['commit-message|m=s'],
+    ['content-from-file|c=s'],
+
     # Merge requests
     ['mr-allow-squash!', 'SALSA_MR_ALLOW_SQUASH', 'bool', 1],
     ['mr-desc=s'],
