@@ -10,7 +10,7 @@ sub transform {
     my $dist    = delete $watchSource->{dist};
     die 'Missing Owner/Project or Dist' unless $dist or ($owner and $project);
     if ($dist) {
-        $dist =~ s#^.*?github\.com#https://api.github.com#;
+        $dist =~ s#^.*?github\.com#https://api.github.com/repos#;
         $dist =~ s/\.git$//;
     } else {
         $dist = "https://api.github.com/repos/$owner/$project";
